@@ -27,3 +27,15 @@ class InvalidResponse(AferoError):
 
 class SecuritySystemError(AferoError):
     """Generic exception for Afero Security System issues."""
+
+
+class OTPError(AferoError):
+    """Issue occurred with OTP authentication."""
+
+
+class OTPRequired(AferoError):
+    """One-time password is required for login."""
+
+
+class InvalidOTP(OTPError):
+    """One-time password provided is invalid."""
