@@ -17,3 +17,10 @@ class EventType(Enum):
     INVALID_AUTH = "invalid_auth"
     POLLED_DATA = "polled_data"
     POLLED_DEVICES = "polled_devices"
+
+
+class TemperatureUnit(Enum):
+    """Temperature unit enum."""
+
+    CELSIUS = "celsius"
+    FAHRENHEIT = "fahrenheit"
